==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicCheckBoxUI.h <==
// public class javax.swing.plaf.basic.BasicCheckBoxUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class c8ed53de641185c javax_swing_plaf_basic_BasicButtonUI
// @dep_class 158197ecd6a10f1f javax_swing_plaf_basic_BasicCheckBoxUI
// @dep_class e766d39c0b1e0642 javax_swing_plaf_basic_BasicRadioButtonUI
// @dep_class 49f2b7dfed6632cf javax_swing_plaf_basic_BasicToggleButtonUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicRadioButtonUI

#include "javax/swing/plaf/basic/BasicRadioButtonUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_
#define _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$getDefaultIcon$b243839d8c323253(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method_info$getDefaultIcon$b243839d8c323253;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method_info$installUI$ddb69f0251b0939f;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods {
	struct _jc_object	*(*getDefaultIcon$b243839d8c323253)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *);
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_basic_BasicButtonUI$vmethods	javax_swing_plaf_basic_BasicButtonUI;
	_jc_javax_swing_plaf_basic_BasicToggleButtonUI$vmethods	javax_swing_plaf_basic_BasicToggleButtonUI;
	_jc_javax_swing_plaf_basic_BasicRadioButtonUI$vmethods	javax_swing_plaf_basic_BasicRadioButtonUI;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods	javax_swing_plaf_basic_BasicCheckBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs {
    _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs	javax_swing_plaf_basic_BasicCheckBoxUI;
    _jc_javax_swing_plaf_basic_BasicRadioButtonUI$sub_refs	javax_swing_plaf_basic_BasicRadioButtonUI;
    _jc_javax_swing_plaf_basic_BasicToggleButtonUI$sub_refs	javax_swing_plaf_basic_BasicToggleButtonUI;
    _jc_javax_swing_plaf_basic_BasicButtonUI$sub_refs	javax_swing_plaf_basic_BasicButtonUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_basic_BasicButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicButtonUI;
    _jc_javax_swing_plaf_basic_BasicToggleButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicToggleButtonUI;
    _jc_javax_swing_plaf_basic_BasicRadioButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicRadioButtonUI;
    _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs	javax_swing_plaf_basic_BasicCheckBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object {
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype _jc_javax_swing_plaf_basic_BasicCheckBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicCheckBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicCheckBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicCheckBoxUI.h <==
// public class javax.swing.plaf.basic.BasicCheckBoxUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5216db2ca259b37f javax_swing_plaf_ButtonUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class d3cab5156f63676b javax_swing_plaf_basic_BasicButtonUI
// @dep_class 158197ecd6a10f1f javax_swing_plaf_basic_BasicCheckBoxUI
// @dep_class e766d39c0b1e0642 javax_swing_plaf_basic_BasicRadioButtonUI
// @dep_class 9d58deda8d79c206 javax_swing_plaf_basic_BasicToggleButtonUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicRadioButtonUI

#include "javax/swing/plaf/basic/BasicRadioButtonUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_
#define _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$getDefaultIcon$b243839d8c323253(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$installUI$ddb69f0251b0939f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method_info$getDefaultIcon$b243839d8c323253;
extern _jc_method _jc_javax_swing_plaf_basic_BasicCheckBoxUI$method_info$installUI$ddb69f0251b0939f;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicCheckBoxUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods {
	struct _jc_object	*(*getDefaultIcon$b243839d8c323253)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *) _JC_JCNI_ATTR;
	void	(*installUI$ddb69f0251b0939f)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ButtonUI$vmethods	javax_swing_plaf_ButtonUI;
	_jc_javax_swing_plaf_basic_BasicButtonUI$vmethods	javax_swing_plaf_basic_BasicButtonUI;
	_jc_javax_swing_plaf_basic_BasicToggleButtonUI$vmethods	javax_swing_plaf_basic_BasicToggleButtonUI;
	_jc_javax_swing_plaf_basic_BasicRadioButtonUI$vmethods	javax_swing_plaf_basic_BasicRadioButtonUI;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vmethods	javax_swing_plaf_basic_BasicCheckBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs {
    _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_refs	javax_swing_plaf_basic_BasicCheckBoxUI;
    _jc_javax_swing_plaf_basic_BasicRadioButtonUI$sub_refs	javax_swing_plaf_basic_BasicRadioButtonUI;
    _jc_javax_swing_plaf_basic_BasicToggleButtonUI$sub_refs	javax_swing_plaf_basic_BasicToggleButtonUI;
    _jc_javax_swing_plaf_basic_BasicButtonUI$sub_refs	javax_swing_plaf_basic_BasicButtonUI;
    _jc_javax_swing_plaf_ButtonUI$sub_refs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ButtonUI$sub_nonrefs	javax_swing_plaf_ButtonUI;
    _jc_javax_swing_plaf_basic_BasicButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicButtonUI;
    _jc_javax_swing_plaf_basic_BasicToggleButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicToggleButtonUI;
    _jc_javax_swing_plaf_basic_BasicRadioButtonUI$sub_nonrefs	javax_swing_plaf_basic_BasicRadioButtonUI;
    _jc_javax_swing_plaf_basic_BasicCheckBoxUI$sub_nonrefs	javax_swing_plaf_basic_BasicCheckBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicCheckBoxUI$object {
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicCheckBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicCheckBoxUI$vtype _jc_javax_swing_plaf_basic_BasicCheckBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicCheckBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicCheckBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicCheckBoxUI_H_ */
